==> owncloud_7.0.0~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/nb_NO.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Dine innstillinger har blit oppdatert",
"Activity" => "Aktivitet",
"A file or folder has been <strong>shared</strong>" => "En fil eller mappe ble <strong>delt</strong>",
"A new file or folder has been <strong>created</strong> in a shared folder" => "En fil eller mappe ble <strong>opprettet</strong> i en delt mappe",
"A file or folder has been <strong>changed</strong> in a shared folder" => "En fil eller mappe ble <strong>endret</strong> i en delt mappe",
"A file or folder has been <strong>deleted</strong> from a shared folder" => "En fil eller mappe ble <strong>slettet</strong> fra en delt mappe",
"You created %1\$s" => "Du slettet %1\$s",
"%2\$s created %1\$s" => "%2\$s opprettet %1\$s",
"You changed %1\$s" => "Du endret %1\$s",
"%2\$s changed %1\$s" => "%2\$s endret %1\$s",
"You deleted %1\$s" => "Du slettet %1\$s",
"%2\$s deleted %1\$s" => "%2\$s slettet %1\$s",
"You shared %1\$s with %2\$s" => "Du delte %1\$s med %2\$s",
"You shared %1\$s with group %2\$s" => "Du delte %1\$s med gruppe %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s delte %1\$s med deg",
"You shared %1\$s via link" => "Du delte %1\$s via lenke",
"Activity notification" => "Varsel om aktivitet",
"All Activities" => "Alle aktiviteter",
"Activities by you" => "Dine aktiviteter",
"Activities by others" => "Andres aktiviteter",
"Shares" => "Delinger",
"Files" => "Filer",
"%s and %s" => "%s og %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s og <strong class=\"tooltip\" title=\"%s\">%n til</strong>","%s og <strong class=\"tooltip\" title=\"%s\">%n flere</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s og %n til","%s og %n flere"),
"Hello %s," => "Hei %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Du mottar denne e-posten fordi følgende har skjedd på %s den siste timen",
"You are receiving this email because in the last day the following things happened at %s" => "Du mottar denne e-posten fordi følgende har skjedd på %s det siste døgnet",
"You are receiving this email because in the last week the following things happened at %s" => "Du mottar denne e-posten fordi følgende har skjedd på %s den siste uken",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Du vil se en liste av hendelser her når du begynner å bruke %s.",
"No more events to load" => "Ingen flere hendelser å laste",
"Enable RSS feed" => "Aktiver RSS-strøm",
"Notifications" => "Varsler",
"Mail" => "E-post",
"Stream" => "Strøm",
"You need to set up your email address before you can receive notification emails." => "Du må sette opp e-postadressen din før du kan motta varslinger på e-post.",
"Send emails:" => "Send e-poster:",
"Hourly" => "Hver time",
"Daily" => "Daglig",
"Weekly" => "Ukentlig",
"Activity feed" => "Aktivitetsstrøm",
"Personal activity feed for %s" => "Personlig aktivitetsstrøm for %s"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud_7.0.1~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/nb_NO.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Dine innstillinger har blit oppdatert",
"Activity" => "Aktivitet",
"A file or folder has been <strong>shared</strong>" => "En fil eller mappe ble <strong>delt</strong>",
"A new file or folder has been <strong>created</strong>" => "En ny fil eller mappe ble <strong>opprettet</strong>",
"A file or folder has been <strong>changed</strong>" => "En fil eller mappe ble <strong>endret</strong>",
"A file or folder has been <strong>deleted</strong>" => "En fil eller mappe ble <strong>slettet</strong>",
"You created %1\$s" => "Du slettet %1\$s",
"%2\$s created %1\$s" => "%2\$s opprettet %1\$s",
"You changed %1\$s" => "Du endret %1\$s",
"%2\$s changed %1\$s" => "%2\$s endret %1\$s",
"You deleted %1\$s" => "Du slettet %1\$s",
"%2\$s deleted %1\$s" => "%2\$s slettet %1\$s",
"You shared %1\$s with %2\$s" => "Du delte %1\$s med %2\$s",
"You shared %1\$s with group %2\$s" => "Du delte %1\$s med gruppe %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s delte %1\$s med deg",
"You shared %1\$s via link" => "Du delte %1\$s via lenke",
"Activity notification" => "Varsel om aktivitet",
"All Activities" => "Alle aktiviteter",
"Activities by you" => "Dine aktiviteter",
"Activities by others" => "Andres aktiviteter",
"Shares" => "Delinger",
"Files" => "Filer",
"%s and %s" => "%s og %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s og <strong class=\"tooltip\" title=\"%s\">%n til</strong>","%s og <strong class=\"tooltip\" title=\"%s\">%n flere</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s og %n til","%s og %n flere"),
"Hello %s," => "Hei %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Du mottar denne e-posten fordi følgende har skjedd på %s den siste timen",
"You are receiving this email because in the last day the following things happened at %s" => "Du mottar denne e-posten fordi følgende har skjedd på %s det siste døgnet",
"You are receiving this email because in the last week the following things happened at %s" => "Du mottar denne e-posten fordi følgende har skjedd på %s den siste uken",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Du vil se en liste av hendelser her når du begynner å bruke %s.",
"No more events to load" => "Ingen flere hendelser å laste",
"Enable RSS feed" => "Aktiver RSS-strøm",
"Notifications" => "Varsler",
"Mail" => "E-post",
"Stream" => "Strøm",
"Notify about my own actions" => "Varsle meg om mine egne handlinger",
"You need to set up your email address before you can receive notification emails." => "Du må sette opp e-postadressen din før du kan motta varslinger på e-post.",
"Send emails:" => "Send e-poster:",
"Hourly" => "Hver time",
"Daily" => "Daglig",
"Weekly" => "Ukentlig",
"Activity feed" => "Aktivitetsstrøm",
"Personal activity feed for %s" => "Personlig aktivitetsstrøm for %s"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
